@@ -745,7 +745,12 @@ on_cursor_callback (GObject      *object,
     success = tracker_sparql_cursor_next_finish (cursor, result, &error);
     if (!success)
     {
-        g_clear_error (&error);
+        if (error)
+        {
+            g_warning ("Error on batch rename tracker query cursor: %s", error->message);
+            g_error_free (error);
+        }
+
         g_clear_object (&cursor);
 
         nautilus_batch_rename_dialog_query_finished (query_data->dialog,
@@ -1129,7 +1134,11 @@ check_metadata_for_selection (NautilusBatchRenameDialog *dialog,
     connection = tracker_sparql_connection_get (NULL, &error);
     if (!connection)
     {
-        g_error_free (error);
+        if (error)
+        {
+            g_warning ("Error on batch rename tracker connection: %s", error->message);
+            g_error_free (error);
+        }
 
         return;
     }
